#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HUnit
version:              1.6.2.0
visibility:           public
id:                   HUnit-1.6.2.0-AT4Mx0wk6OXAfe1KUqjGNi
key:                  HUnit-1.6.2.0-AT4Mx0wk6OXAfe1KUqjGNi
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  327b2d7e37337e24826c9bf2a1e6caea
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/HUnit-1.6.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/HUnit-1.6.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/HUnit-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hunit
hs-libraries:         HSHUnit-1.6.2.0-AT4Mx0wk6OXAfe1KUqjGNi
depends:
    base-4.18.2.1 call-stack-0.4.0-Cy9xJTJdicU5c9ivm2ABko
    deepseq-1.4.8.1

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

